const app = new Vue({
  el: "#app",
  data() {
    return {
      i18n: {},
      checking: false,
      checkProcessStyle: {},
      bookmarksCount: 0,
      bookmarksList: [],
      clearIdList: [],
      dialogVisible: false,
    };
  },
  created() {
    this.getBookmarksCount();
    setTimeout(() => {
      this.i18n = loadTimeData.data_;
    }, 0);
  },
  computed: {
    clearDisabled() {
      return this.checking || this.clearIdList.length === 0;
    },
  },
  methods: {
    // 获取书签总数
    getBookmarksCount() {
      chrome.send("getBookmarksCount", ["callback_getCount"]);
      window.callback_getCount = (res) => {
        this.bookmarksCount = res;
      };
    },
    // 开始检测
    checkStart() {
      this.checking = true;
      chrome.send("checkStart", ["callback_checkStart"]);
    },
    // 触发事件
    checkSuccess(res) {
      if (res.invalid) this.clearIdList.push(res.id);
      this.bookmarksList.push({ ...res, checked: res.invalid });
      this.checking = this.bookmarksList.length !== this.bookmarksCount;
      this.checkProcessStyle = { width: `${(this.bookmarksList.length / this.bookmarksCount) * 100}%` };
    },
    // 暂停检测
    checkPause() {
      this.checking = false;
      chrome.send("checkPause");
    },
    // 排序
    sortItems(type) {
      if (this.checking) return;
      this.bookmarksList = this.bookmarksList.sort((a, b) => {
        if (type === 1) {
          return a.invalid - b.invalid;
        } else {
          return b.invalid - a.invalid;
        }
      });
    },
    // 默认图片
    getDefaultIcon(item) {
      item.favicon_url = "./img/site.png";
    },
    // 选择书签
    selectItems() {
      this.clearIdList = [];
      this.bookmarksList.forEach((item) => {
        if (item.checked) this.clearIdList.push(item.id);
      });
    },
    // 打开弹窗
    openDialog() {
      if (this.clearDisabled) return;
      this.dialogVisible = true;
    },
    // 删除书签
    removeBookmarks() {
      chrome.send("removeBookmarks", this.clearIdList);
      this.dialogVisible = false;
      this.bookmarksCount -= this.clearIdList.length;
      this.bookmarksList = this.bookmarksList.filter((item) => this.clearIdList.indexOf(item.id) === -1);
    },
  },
});

// 开始检测后抛出通知
const notifyBookmarkResult = app.checkSuccess;
